@@ -79,7 +79,8 @@ NSString *const VLCPasscodeValidated = @"VLCPasscodeValidated";
                                   kVLCSettingSubtitlesBoldFont: kVLCSettingSubtitlesBoldFontDefaultValue,
                                   kVLCSettingDeinterlace : kVLCSettingDeinterlaceDefaultValue,
                                   kVLCSettingNetworkCaching : kVLCSettingNetworkCachingDefaultValue,
-                                  kVLCSettingPlaybackGestures : [NSNumber numberWithBool:YES],
+                                  kVLCSettingPlaybackGestures : @(YES),
+                                  kVLCSettingVideoFullscreenPlayback : @(YES),
                                   kVLCSettingFTPTextEncoding : kVLCSettingFTPTextEncodingDefaultValue,
                                   kVLCSettingWiFiSharingIPv6 : kVLCSettingWiFiSharingIPv6DefaultValue,
                                   kVLCSettingEqualizerProfile : kVLCSettingEqualizerProfileDefaultValue,
@@ -544,6 +545,12 @@ continueUserActivity:(NSUserActivity *)userActivity
     [self.menuViewController selectRowAtIndexPath:[NSIndexPath indexPathForRow:2 inSection:1] animated:NO scrollPosition:UITableViewScrollPositionNone];
 }
 
+#pragma mark - remote events pre 7.1
+
+- (void)remoteControlReceivedWithEvent:(UIEvent *)event {
+    [[VLCPlaybackController sharedInstance] remoteControlReceivedWithEvent:event];
+}
+
 #pragma mark - playback view handling
 
 - (void)openMediaFromManagedObject:(NSManagedObject *)mediaObject
@@ -561,6 +568,7 @@ continueUserActivity:(NSUserActivity *)userActivity
     vpc.url = url;
     vpc.successCallback = successCallback;
     vpc.errorCallback = errorCallback;
+    vpc.fullscreenSessionRequested = YES;
 
     [vpc startPlayback];
 }
@@ -576,6 +584,7 @@ continueUserActivity:(NSUserActivity *)userActivity
 
     vpc.url = url;
     vpc.pathToExternalSubtitlesFile = SubtitlePath;
+    vpc.fullscreenSessionRequested = YES;
 
     [vpc startPlayback];
 }
