@@ -376,6 +376,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
         } else
             _sleepTimeDatePicker.backgroundColor = [UIColor blackColor];
         _sleepTimeDatePicker.tintColor = [UIColor VLCLightTextColor];
+        _sleepTimeDatePicker.frame = CGRectMake(0., 0., 300., 162.);
         _sleepTimeDatePicker.autoresizingMask = UIViewAutoresizingFlexibleRightMargin | UIViewAutoresizingFlexibleLeftMargin | UIViewAutoresizingFlexibleBottomMargin | UIViewAutoresizingFlexibleTopMargin;
         [_sleepTimerContainer addSubview:_sleepTimeDatePicker];
 
@@ -538,7 +539,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
         return;
 
     if (recognizer.velocity < 0.)
-        [self closePlayback:nil];
+        [self minimizePlayback:nil];
 }
 
 - (BOOL)gestureRecognizer:(UIGestureRecognizer *)gestureRecognizer shouldReceiveTouch:(UITouch *)touch
@@ -687,9 +688,15 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
 - (IBAction)closePlayback:(id)sender
 {
     LOCKCHECK;
-    [[UIApplication sharedApplication] sendAction:@selector(closeFullscreenPlayback) to:nil from:self forEvent:nil];
-
+    [[VLCPlaybackController sharedInstance] stopPlayback];
 }
+
+- (IBAction)minimizePlayback:(id)sender
+{
+    LOCKCHECK;
+    [[UIApplication sharedApplication] sendAction:@selector(closeFullscreenPlayback) to:nil from:self forEvent:nil];
+}
+
 - (IBAction)positionSliderAction:(UISlider *)sender
 {
     LOCKCHECK;
@@ -826,7 +833,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
         self.brightnessSlider.value = [UIScreen mainScreen].brightness * 2.;
     [_equalizerView reloadData];
 
-    float playbackRate = controller.playbackRate;
+    double playbackRate = controller.playbackRate;
     self.playbackSpeedSlider.value = log2(playbackRate);
     self.playbackSpeedIndicator.text = [NSString stringWithFormat:@"%.2fx", playbackRate];
 
@@ -843,7 +850,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
 
 - (void)playbackDidStop:(NSNotification *)notification
 {
-    [self closePlayback:nil];
+    [self minimizePlayback:nil];
 }
 
 - (void)mediaPlayerStateChanged:(VLCMediaPlayerState)currentState
